#! /usr/bin/env python

import logging, logtool, os, psutil, socket
from celery import Celery
from celery.signals import setup_logging
from django.conf import settings

LOG = logging.getLogger (__name__)
DEFAULT_LOGCONF = "/etc/qworkerd/logging.conf"

os.environ.setdefault ("DJANGO_SETTINGS_MODULE", "qworkerd.settings")
app = Celery ("qworkerd")
app.config_from_object ("django.conf:settings")
app.autodiscover_tasks (lambda: settings.INSTALLED_APPS)
app.set_current ()

@setup_logging.connect
#@logtool.log_call
def setup_logging_handler (**kwargs): # pylint: disable=W0613
  logging.config.fileConfig (DEFAULT_LOGCONF,
                             disable_existing_loggers = False)

@app.task
@logtool.log_call
def status ():
  rc = {
    "hostname": socket.gethostname (),
    "cpu": {
      "count": psutil.cpu_count (),
      "times": psutil.cpu_times (),
      "percent": psutil.cpu_percent (percpu = True),
      },
    "memory": {
      "virtual": psutil.virtual_memory (),
      "swap": psutil.swap_memory (),
      },
    "net": psutil.net_io_counters (),
    "uptime": {
      "ut": psutil.boot_time (),
      "since": logtool.time_str (psutil.boot_time (), slug = True),
      },
    "disk": {},
    "process": {},
    }
  for part in psutil.disk_partitions ():
    rc["disk"]["mounts"] = {
      part.mountpoint: psutil.disk_usage (part.mountpoint),
    }
  for disk, io in psutil.disk_io_counters (perdisk = True).items ():
    rc["disk"]["io"] = {
      disk: io
    }
  for proc in psutil.process_iter ():
    if proc.username == settings.UNIX_USER:
      rc["process"]["proc.pid"] = {
        "name": proc.name,
        "exe": proc.exe,
        "cmdline": proc.cmdline,
        "create_time": proc.create_time (),
        "since":  logtool.time_str (proc.create_time (), slug = True),
        "status": proc.status (),
        "cpu.times": proc.cpu_times (),
        "cpu.percent": proc.cpu_percent (),
        "memory.info": proc.memory_info_ex (),
        "percent": proc.memory_percent (),
      }
  return rc

if __name__ == "__main__":
  app.start()



#! /usr/bin/env python

try:
  import pyver
except ImportError:
  import pip
  pip.main (['install', 'pyver'])
  import pyver # pylint: disable=W0611

from setuptools import setup, find_packages
import glob

__version__, __version_info__ = pyver.get_version (pkg = "qworkerd",
                                                   public = True)

setup (
    name = "qworkerd",
    version = __version__,
    description = "Celery disk-job based worker",
    long_description = file ("README.rst").read (),
    classifiers = [],
    keywords = "celery, worker, disk job",
    author = "J C Lawrence",
    author_email = "claw@kanga.nu",
    url = "http://kanga.nu/~claw/",
    license = "GPL v3.0",
    packages = find_packages (exclude = ["tests"]),
    package_data = {"qworkerd": ["_cfgtool/qworkerd",
                                 "_cfgtool/*.templ",
                                 "_cfgtool/install",],
    },
    data_files = [
        ("/etc/cfgtool/module.d/", ["qworkerd/_cfgtool/qworkerd",]),
        ("/etc/qworkerd", glob.glob ("qworkerd/_cfgtool/*.templ")),
        ("./bin", ["qworkerd/qworkerd_manage.py"]),
    ],
    zip_safe = False,
    install_requires = [line.strip ()
                        for line in file ("requirements.txt").readlines ()],
    entry_points = {
        "console_scripts": [
        ],
    },
)
